==> amplify_flutter-0.0.2-dev.2.tar.gz: lib/categories/amplify_categories.dart <==
/*
 * Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

library amplify_interface;

import 'dart:async';
import 'dart:io';

import 'package:amplify_analytics_plugin_interface/analytics_plugin_interface.dart';
import 'package:amplify_auth_plugin_interface/amplify_auth_plugin_interface.dart';
import 'package:amplify_datastore_plugin_interface/amplify_datastore_plugin_interface.dart';
import 'package:amplify_storage_plugin_interface/amplify_storage_plugin_interface.dart';
import 'package:amplify_api_plugin_interface/amplify_api_plugin_interface.dart';
import 'package:amplify_core/types/index.dart';
import 'package:flutter/foundation.dart';

/// category parts
part 'amplify_analytics_category.dart';
part 'amplify_auth_category.dart';
part 'amplify_datastore_category.dart';
part 'amplify_storage_category.dart';
part 'amplify_api_category.dart';

_errorMsgPluginNotAdded(String pluginName) =>
    "$pluginName plugin has not been added to Amplify";

_recoverySuggestionPluginNotAdded(String pluginName) =>
    "Add $pluginName plugin to Amplify and call configure before calling $pluginName related APIs";

_pluginNotAddedException(String pluginName) =>
    AmplifyException(_errorMsgPluginNotAdded(pluginName),
        recoverySuggestion: _recoverySuggestionPluginNotAdded(pluginName));

==> amplify_flutter-0.1.0.tar.gz: lib/categories/amplify_categories.dart <==
/*
 * Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

library amplify_interface;

import 'dart:async';
import 'dart:io';

import 'package:amplify_analytics_plugin_interface/amplify_analytics_plugin_interface.dart';
import 'package:amplify_auth_plugin_interface/amplify_auth_plugin_interface.dart';
import 'package:amplify_datastore_plugin_interface/amplify_datastore_plugin_interface.dart';
import 'package:amplify_storage_plugin_interface/amplify_storage_plugin_interface.dart';
import 'package:amplify_api_plugin_interface/amplify_api_plugin_interface.dart';
import 'package:amplify_core/types/index.dart';
import 'package:flutter/foundation.dart';

/// category parts
part 'amplify_analytics_category.dart';
part 'amplify_auth_category.dart';
part 'amplify_datastore_category.dart';
part 'amplify_storage_category.dart';
part 'amplify_api_category.dart';

_errorMsgPluginNotAdded(String pluginName) =>
    "$pluginName plugin has not been added to Amplify";

_recoverySuggestionPluginNotAdded(String pluginName) =>
    "Add $pluginName plugin to Amplify and call configure before calling $pluginName related APIs";

_pluginNotAddedException(String pluginName) =>
    AmplifyException(_errorMsgPluginNotAdded(pluginName),
        recoverySuggestion: _recoverySuggestionPluginNotAdded(pluginName));
